==> jscope_sdk-1.3.0r03.zip: jscope_sdk-1.3.0/lib/dcomponent/dcomponent_widget-1.1.0-min.js <==

DComponent.Validator=Class.cast({Abstract:{validate:null},newInstance:function(){}});DComponent.RequiredValidator=Class.cast({Extends:DComponent.Validator,newInstance:function(){this.superClass();},validate:function(w){var d=w.loadValue();return(d!==null&&d!=="");}});DComponent.RegExpValidator=Class.cast({Extends:DComponent.Validator,_regexp:null,newInstance:function(r){this.superClass();this._regexp=new RegExp(r);},validate:function(w){var d=w.loadValue();return this._regexp.exec(w.loadValue())!=null;}});DComponent.WidgetErrorMessageGenerator={getErrorMessage:null};DComponent.Widget=Class.cast({Extends:DComponent,Virtual:{loadValue:function(){return this.material().value;},setValue:function(v){this.material().value=v;}},_ems:null,_validators:null,_id:null,newInstance:function(e,req,dc){this.superClass(e);this._validators=[];if(req){this.addValidator(new DComponent.RequiredValidator());}
if(dc){this.attachDesign(dc);}},addValidator:function(v){this._validators.push(v);return this;},validate:function(emg){var fc=0;this._ems=[];for(var i=0,v;v=this._validators[i];i++){if(v.validate(this)===false){this._ems.push(emg.getErrorMessage(this,v));fc++;}}
return fc===0;},getValidatorCount:function(){return this._validators.length;},getErrors:function(){return this._ems;},isEnabled:function(){return this._().disabled!=true;},setEnabled:function(b){this._().disabled=!b;}});DComponent.WidgetContainer=Class.cast({Virtual:{validate:function(emg){if(emg.interfaceof&&emg.interfaceof(DComponent.WidgetErrorMessageGenerator)){this._eps={};var fc=0;for(var id in this._widgets){var w=this._widgets[id];if(w.validate(emg)===false){this._eps[id]=w._ems;fc++;}}
return fc===0;}
else{throw new Error("Parameter must implement \"DComponent.WidgetErrorMessageGenerator\" interface.");}}},_container:null,_widgets:null,_validators:null,_eps:null,newInstance:function(c){if(!(c instanceof DComponent)){throw new Error("Parameter is not compoent.");}
this._container=c;this._widgets={};this._validators=[];},addValidator:function(v){this._validators.push(v);return this;},getComponent:function(){return this._container;},addWidget:function(w){if(!(w instanceof DComponent.Widget)){throw new Error("Parameter is not widget.");}
this._widgets[w.getID()]=w;return this;},getWidget:function(id){return this._widgets[id];},getAllErrors:function(){return this._eps;},getWidgetError:function(w){return this._eps[w.getID()];}});DComponent.Form=Class.cast({Extends:DComponent,newInstance:function(id,dc){var e=document.createElement("form");e.id=id;this.superClass(e);if(dc){this.attachDesign(dc);}
e.onSubmit=function(){return false;}
this.setEvent(DComponent.handler(this,this.onSubmit),null,["submit"],false);},addQueryValue:function(id,v){var q=document.createElement("hidden");q.id=id;q.value=v;this.append(new DComponent(q));},submit:function(){this.material().submit();},reset:function(){this.material().reset();},onSubmit:function(e){if(!this.getAttribute("action")){e.preventDefault();}}});DComponent.Input=Class.cast({Extends:DComponent.Widget,newInstance:function(id,type,req,dc){var e=document.createElement("input");e.id=id;e.type=type;this.superClass(e,req,dc);e.addEventListener("keypress",function(es){var e=es||window.event;return e.keyCode!==13;},true);}});DComponent.TextField=Class.cast({Extends:DComponent.Input,newInstance:function(id,req,dc,ph,size,max){this.superClass(id,"text",req,dc);if(ph){this.setAttribute("placeholder",ph);}
if(size){this.setAttribute("size",size);}
if(max){this.setAttribute("maxlength",max);}}});DComponent.PasswordTextField=Class.cast({Extends:DComponent.Input,newInstance:function(id,dc,size,max){this.superClass(id,"password",true,dc);if(size){this.setAttribute("size",size);}
if(max){this.setAttribute("maxlength",max);}}});DComponent.TypedInput=Class.cast({Extends:DComponent.Input,newInstance:function(id,type,dc){this.superClass(id,type,true,dc);}});DComponent.Radio=Class.cast({Extends:DComponent.Input,newInstance:function(id,gn,c,dc){this.superClass(id,"radio",false,dc);this.setAttribute("name",gn);this.material().checked=c||false;},isChecked:function(){return this.material().checked;}});DComponent.CheckBox=Class.cast({Extends:DComponent.Input,newInstance:function(id,c,dc){this.superClass(id,"checkbox",false,dc);this.material().checked=c||false;},isChecked:function(){return this.material().checked;}});DComponent.Select=Class.cast({Extends:DComponent.Widget,newInstance:function(id,req,m,sz,dc){var s=document.createElement("select");s.id=id;if(m){s.multiple="multiple";}
if(sz){s.size=sz;}
this.superClass(s,req,dc);},loadValue:function(){var v=[];var options=this.material().options;for(var i=0,o;o=options[i];i++){if(o.selected&&!o.disabled){if(o.value){v.push(o.value);}}}
return v.length>0?v:null;},getSelectedIndex:function(){return this.material().selectedIndex;},setSelectedIndex:function(i){return this.material().selectedIndex=i;},getOptionCount:function(){return this.material().length;},getTextAt:function(i){return this.material().options[i].text;},getValueAt:function(i){return this.material().options[i].value;},isSelectedAt:function(i){return this.material().options[i].selected;},setTextAt:function(i,t){this.material().options[i].text=t;return this;},addOption:function(t,v,s,d){var o=new Option(t,v,s);if(d){o.disabled="disabled";}
this.material().options.add(o);return this;}});DComponent.TextArea=Class.cast({Extends:DComponent.Widget,newInstance:function(id,req,dc,ph,rows,cols){var e=document.createElement("textarea");e.id=id;if(rows){e.rows=rows;}
if(cols){e.cols=cols;}
this.superClass(e,req,dc);if(ph){this.setAttribute("placeholder",ph);}}});

==> jscope_sdk-1.5.0r09.zip: jscope_sdk-1.5.0/lib/dcomponent/dcomponent_widget-1.1.0-min.js <==

DComponent.Validator=Class.cast({Abstract:{validate:null},newInstance:function(){}});DComponent.RequiredValidator=Class.cast({Extends:DComponent.Validator,newInstance:function(){this.superClass();},validate:function(w){var d=w.loadValue();return(d!==null&&d!=="");}});DComponent.RegExpValidator=Class.cast({Extends:DComponent.Validator,_regexp:null,newInstance:function(r){this.superClass();this._regexp=new RegExp(r);},validate:function(w){var d=w.loadValue();return this._regexp.exec(w.loadValue())!=null;}});DComponent.WidgetErrorMessageGenerator={getErrorMessage:null};DComponent.Widget=Class.cast({Extends:DComponent,Virtual:{loadValue:function(){return this.material().value;},setValue:function(v){this.material().value=v;}},_ems:null,_validators:null,_id:null,newInstance:function(e,req,dc){this.superClass(e);this._validators=[];if(req){this.addValidator(new DComponent.RequiredValidator());}
if(dc){this.attachDesign(dc);}},addValidator:function(v){this._validators.push(v);return this;},validate:function(emg){var fc=0;this._ems=[];for(var i=0,v;v=this._validators[i];i++){if(v.validate(this)===false){this._ems.push(emg.getErrorMessage(this,v));fc++;}}
return fc===0;},getValidatorCount:function(){return this._validators.length;},getErrors:function(){return this._ems;},isEnabled:function(){return this._().disabled!=true;},setEnabled:function(b){this._().disabled=!b;}});DComponent.WidgetContainer=Class.cast({Virtual:{validate:function(emg){if(Class.interfaceOf(emg,DComponent.WidgetErrorMessageGenerator)){this._eps={};var fc=0;for(var id in this._widgets){var w=this._widgets[id];if(w.validate(emg)===false){this._eps[id]=w._ems;fc++;}}
return fc===0;}
else{throw new Error("Parameter must implement \"DComponent.WidgetErrorMessageGenerator\" interface.");}}},_container:null,_widgets:null,_validators:null,_eps:null,newInstance:function(c){if(!(c instanceof DComponent)){throw new Error("Parameter is not compoent.");}
this._container=c;this._widgets={};this._validators=[];},addValidator:function(v){this._validators.push(v);return this;},getComponent:function(){return this._container;},addWidget:function(w){if(!(w instanceof DComponent.Widget)){throw new Error("Parameter is not widget.");}
this._widgets[w.getID()]=w;return this;},getWidget:function(id){return this._widgets[id];},getAllErrors:function(){return this._eps;},getWidgetError:function(w){return this._eps[w.getID()];}});DComponent.Form=Class.cast({Extends:DComponent,newInstance:function(id,dc){var e=document.createElement("form");e.id=id;this.superClass(e);if(dc){this.attachDesign(dc);}
e.onSubmit=function(){return false;}
this.setEvent(DComponent.handler(this,this.onSubmit),null,["submit"],false);},addQueryValue:function(id,v){var q=document.createElement("hidden");q.id=id;q.value=v;this.append(new DComponent(q));},submit:function(){this.material().submit();},reset:function(){this.material().reset();},onSubmit:function(e){if(!this.getAttribute("action")){e.preventDefault();}}});DComponent.Input=Class.cast({Extends:DComponent.Widget,newInstance:function(id,type,req,dc){var e=document.createElement("input");e.id=id;e.type=type;this.superClass(e,req,dc);e.addEventListener("keypress",function(es){var e=es||window.event;return e.keyCode!==13;},true);}});DComponent.TextField=Class.cast({Extends:DComponent.Input,newInstance:function(id,req,dc,ph,size,max){this.superClass(id,"text",req,dc);if(ph){this.setAttribute("placeholder",ph);}
if(size){this.setAttribute("size",size);}
if(max){this.setAttribute("maxlength",max);}}});DComponent.PasswordTextField=Class.cast({Extends:DComponent.Input,newInstance:function(id,dc,size,max){this.superClass(id,"password",true,dc);if(size){this.setAttribute("size",size);}
if(max){this.setAttribute("maxlength",max);}}});DComponent.TypedInput=Class.cast({Extends:DComponent.Input,newInstance:function(id,type,dc){this.superClass(id,type,true,dc);}});DComponent.Radio=Class.cast({Extends:DComponent.Input,newInstance:function(id,gn,c,dc){this.superClass(id,"radio",false,dc);this.setAttribute("name",gn);this.material().checked=c||false;},isChecked:function(){return this.material().checked;}});DComponent.CheckBox=Class.cast({Extends:DComponent.Input,newInstance:function(id,c,dc){this.superClass(id,"checkbox",false,dc);this.material().checked=c||false;},isChecked:function(){return this.material().checked;}});DComponent.Select=Class.cast({Extends:DComponent.Widget,newInstance:function(id,req,m,sz,dc){var s=document.createElement("select");s.id=id;if(m){s.multiple="multiple";}
if(sz){s.size=sz;}
this.superClass(s,req,dc);},loadValue:function(){var v=[];var options=this.material().options;for(var i=0,o;o=options[i];i++){if(o.selected&&!o.disabled){if(o.value){v.push(o.value);}}}
return v.length>0?v:null;},getSelectedIndex:function(){return this.material().selectedIndex;},setSelectedIndex:function(i){return this.material().selectedIndex=i;},getOptionCount:function(){return this.material().length;},getTextAt:function(i){return this.material().options[i].text;},getValueAt:function(i){return this.material().options[i].value;},isSelectedAt:function(i){return this.material().options[i].selected;},setTextAt:function(i,t){this.material().options[i].text=t;return this;},addOption:function(t,v,s,d){var o=new Option(t,v,s);if(d){o.disabled="disabled";}
this.material().options.add(o);return this;}});DComponent.TextArea=Class.cast({Extends:DComponent.Widget,newInstance:function(id,req,dc,ph,rows,cols){var e=document.createElement("textarea");e.id=id;if(rows){e.rows=rows;}
if(cols){e.cols=cols;}
this.superClass(e,req,dc);if(ph){this.setAttribute("placeholder",ph);}}});
